// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
import { __awaiter, __extends, __generator } from "tslib";
import { BaseRequestPolicy } from "./requestPolicy";
/**
 * Returns a request policy factory that can be used to create an instance of
 * {@link DisableResponseDecompressionPolicy}.
 */
export function disableResponseDecompressionPolicy() {
    return {
        create: function (nextPolicy, options) {
            return new DisableResponseDecompressionPolicy(nextPolicy, options);
        }
    };
}
/**
 * A policy to disable response decompression according to Accept-Encoding header
 * https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Encoding
 */
var DisableResponseDecompressionPolicy = /** @class */ (function (_super) {
    __extends(DisableResponseDecompressionPolicy, _super);
    /**
     * Creates an instance of DisableResponseDecompressionPolicy.
     *
     * @param nextPolicy -
     * @param options -
     */
    // The parent constructor is protected.
    /* eslint-disable-next-line @typescript-eslint/no-useless-constructor */
    function DisableResponseDecompressionPolicy(nextPolicy, options) {
        return _super.call(this, nextPolicy, options) || this;
    }
    /**
     * Sends out request.
     *
     * @param request -
     * @returns
     */
    DisableResponseDecompressionPolicy.prototype.sendRequest = function (request) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                request.decompressResponse = false;
                return [2 /*return*/, this._nextPolicy.sendRequest(request)];
            });
        });
    };
    return DisableResponseDecompressionPolicy;
}(BaseRequestPolicy));
export { DisableResponseDecompressionPolicy };
//# sourceMappingURL=disableResponseDecompressionPolicy.js.map