import { Context } from '@opentelemetry/context-base';
import { GetterFunction } from '../context/propagation/getter';
import { HttpTextPropagator } from '../context/propagation/HttpTextPropagator';
import { SetterFunction } from '../context/propagation/setter';
/**
 * Singleton object which represents the entry point to the OpenTelemetry Propagation API
 */
export declare class PropagationAPI {
    private static _instance?;
    /** Empty private constructor prevents end users from constructing a new instance of the API */
    private constructor();
    /** Get the singleton instance of the Propagator API */
    static getInstance(): PropagationAPI;
    /**
     * Set the current propagator. Returns the initialized propagator
     */
    setGlobalPropagator(propagator: HttpTextPropagator): HttpTextPropagator;
    /**
     * Inject context into a carrier to be propagated inter-process
     *
     * @param carrier carrier to inject context into
     * @param setter Function used to set values on the carrier
     * @param context Context carrying tracing data to inject. Defaults to the currently active context.
     */
    inject<Carrier>(carrier: Carrier, setter?: SetterFunction<Carrier>, context?: Context): void;
    /**
     * Extract context from a carrier
     *
     * @param carrier Carrier to extract context from
     * @param getter Function used to extract keys from a carrier
     * @param context Context which the newly created context will inherit from. Defaults to the currently active context.
     */
    extract<Carrier>(carrier: Carrier, getter?: GetterFunction<Carrier>, context?: Context): Context;
    /** Remove the global propagator */
    disable(): void;
    private _getGlobalPropagator;
}
//# sourceMappingURL=propagation.d.ts.map